rnalysis.filtering.HTCountFilter.norm\_reads\_with\_size\_factor
================================================================

.. currentmodule:: rnalysis.filtering

.. automethod:: HTCountFilter.norm_reads_with_size_factor